@@ -1,12 +1,11 @@
 //! Bit-shift helpers.
 
-use crate::lib::mem;
 use super::float::ExtendedFloat;
+use crate::lib::mem;
 
 // Shift extended-precision float right `shift` bytes.
 #[inline]
-pub(crate) fn shr(fp: &mut ExtendedFloat, shift: i32)
-{
+pub(crate) fn shr(fp: &mut ExtendedFloat, shift: i32) {
     let bits: u64 = mem::size_of::<u64>() as u64 * 8;
     debug_assert!((shift as u64) < bits, "shr() overflow in shift right.");
 
@@ -19,13 +18,12 @@ pub(crate) fn shr(fp: &mut ExtendedFloat, shift: i32)
 // Accepts when the shift is the same as the type size, and
 // sets the value to 0.
 #[inline]
-pub(crate) fn overflowing_shr(fp: &mut ExtendedFloat, shift: i32)
-{
+pub(crate) fn overflowing_shr(fp: &mut ExtendedFloat, shift: i32) {
     let bits: u64 = mem::size_of::<u64>() as u64 * 8;
     debug_assert!((shift as u64) <= bits, "overflowing_shr() overflow in shift right.");
 
     fp.mant = match shift as u64 == bits {
-        true  => 0,
+        true => 0,
         false => fp.mant >> shift,
     };
     fp.exp += shift;
@@ -33,8 +31,7 @@ pub(crate) fn overflowing_shr(fp: &mut ExtendedFloat, shift: i32)
 
 // Shift extended-precision float left `shift` bytes.
 #[inline]
-pub(crate) fn shl(fp: &mut ExtendedFloat, shift: i32)
-{
+pub(crate) fn shl(fp: &mut ExtendedFloat, shift: i32) {
     let bits: u64 = mem::size_of::<u64>() as u64 * 8;
     debug_assert!((shift as u64) < bits, "shl() overflow in shift left.");
 
